@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package IPv6::Address;
-$IPv6::Address::VERSION = '0.206';
+$IPv6::Address::VERSION = '0.207';
 
 =head1 NAME
 
@@ -10,7 +10,7 @@ IPv6::Address - IPv6 Address Manipulation Library
 
 =head1 VERSION
 
-version 0.206
+version 0.207
 
 =for html
 <a href="https://travis-ci.org/aduitsis/IPv6-Address"><img src="https://travis-ci.org/aduitsis/IPv6-Address.svg?branch=master"></a>
@@ -635,7 +635,7 @@ sub radius_string {
 }
 
 package IPv4Subnet;
-$IPv4Subnet::VERSION = '0.206';
+$IPv4Subnet::VERSION = '0.207';
 use Socket;
 use strict;
 use Carp;
@@ -683,7 +683,14 @@ sub get_length {
 }
 
 sub enumerate {
-	map { my_ntoa( $_ ) } ($_[0]->get_start .. $_[0]->get_stop)
+	# in 32-bit systems, this seems to fail with error:
+	# "Range iterator outside integer range"
+	#map { my_ntoa( $_ ) } ($_[0]->get_start .. $_[0]->get_stop)
+	my @ret;
+	for( my $i = $_[0]->get_start ; $i <= $_[0]->get_stop ; $i++ ) {
+		push @ret,my_ntoa( $i )
+	}
+	return @ret
 }
 
 sub get_length_n {
